@@ -10,6 +10,7 @@ import com.fasterxml.jackson.annotation.JsonIgnore;
 import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.fasterxml.jackson.annotation.JsonPropertyOrder;
+
 import com.fasterxml.jackson.jr.ob.impl.JSONReader;
 import com.fasterxml.jackson.jr.ob.impl.JSONWriter;
 import com.fasterxml.jackson.jr.ob.impl.POJODefinition;
@@ -220,7 +221,20 @@ public class AnnotationBasedIntrospector
     }
 
     protected void _findFields() {
-        for (Field f : _type.getDeclaredFields()) {
+        _findFields(_type);
+    }
+
+    protected void _findFields(final Class<?> currType)
+    {
+        if (currType == null || currType == Object.class) {
+            return;
+        }
+        // [jackson-jr#76]: Was not doing recursive field detection
+        // Start with base type fields (so overrides work)
+        _findFields(currType.getSuperclass());
+
+        // then get fields from within class itself
+        for (Field f : currType.getDeclaredFields()) {
             // Does not include static fields, but there are couple of things we do
             // not include regardless:
             if (f.isEnumConstant() || f.isSynthetic()) {
